@@ -33,7 +33,8 @@ class UnicodeTestCase(unittest.TestCase):
         # check accessing individual attributes.
         assert f.attribute1 == ATT1
         assert f.attribute2 == ATT2
-        assert f.attribute3 == ''.join(ATT3)
+        #assert f.attribute3 == ''.join(ATT3)
+        assert f.attribute3 == ATT3 # behavior changed issue 770
         f.close()
 
 if __name__ == '__main__':
